Index: src/ic/stub-cache.cc |
diff --git a/src/ic/stub-cache.cc b/src/ic/stub-cache.cc |
index 9655cc4bbc82dfea5b6501282b5b5b9c52edd4eb..84dbf48436ed35d1ab6d995785aa21d49072463e 100644 |
--- a/src/ic/stub-cache.cc |
+++ b/src/ic/stub-cache.cc |
@@ -30,9 +30,10 @@ namespace { |
bool CommonStubCacheChecks(StubCache* stub_cache, Name* name, Map* map, |
Object* handler) { |
// Validate that the name does not move on scavenge, and that we |
// can use identity checks instead of structural equality checks. |
DCHECK(!name->GetHeap()->InNewSpace(name)); |
+ DCHECK(!name->GetHeap()->InNewSpace(handler)); |
DCHECK(name->IsUniqueName()); |
DCHECK(name->HasHashCode()); |
if (handler) { |
@@ -30,9 +30,10 @@ namespace { |
bool CommonStubCacheChecks(StubCache* stub_cache, Name* name, Map* map, |
Object* handler) { |
- // Validate that the name does not move on scavenge, and that we |
+ // Validate that the name and handler do not move on scavenge, and that we |
// can use identity checks instead of structural equality checks. |
DCHECK(!name->GetHeap()->InNewSpace(name)); |